@@ -6,7 +6,6 @@ import base64
 import logging
 
 from pathlib import Path
-from functools import wraps
 from datetime import datetime
 from werkzeug.wrappers import Response
 from urllib.parse import urlparse, unquote
@@ -408,7 +407,6 @@ def handle_exceptions(function=None, is_lambda: bool = False, return_html: bool
         OSError: If file was not written correctly this error will raise
     """
 
-    @wraps(function)
     def wrapper(*args, **kwargs):
         try:
             return function(*args, **kwargs)
